# Fixed_data directory
This directory contains all of the fixes that are made to the data directory.  If you rerun the all_parser.py module,
you need to recursively copy the contents of this directory over data.

Note: We may want to consider enhancing the test suite to look here first...